# LunesPy

📦 Library for communication with nodes in mainnet or testnet of the lunes-blockchain network Allows the automation of sending assets, issue end reissue tokens, leasing, registry, and create new wallet.

[![Test](https://github.com/lunes-platform/lunespy/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/lunes-platform/lunespy/actions/workflows/test.yml)
![PyPI](https://img.shields.io/pypi/v/lunespy)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/lunespy)

![PyPI - Downloads](https://img.shields.io/pypi/dm/lunespy)
![GitHub last commit](https://img.shields.io/github/last-commit/lunes-platform/lunespy)
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/lunes-platform/lunespy)

![PyPI - License](https://img.shields.io/pypi/l/lunespy)
![Discord](https://img.shields.io/discord/958424925453058158)
## Documentation

The `lunespy` documentations is hosted at [Telescope](https://lunes-platform.github.io/telescope/)

## Changelog

The changelog process for this project is described [here](CHANGELOG.md).

## Contributing

`lunespy` is still under development. Contributions are always welcome! Please follow the [Developers Guide](CONTRIBUTING.md) if you want to help.

Thanks to the following people who have contributed to this project:

- [olivmath](https://github.com/olivmath)
- [marcoslkz](https://github.com/marcoslkz)
- [VanJustin](https://github.com/VanJustin)
- [xonfps](https://github.com/xonfps)

## Contact

If you want to contact me you can reach me at <development@lunes.io>.

## License

[Apache License Version 2.0](https://github.com/lunes-platform/lunespy/blob/main/LICENSE).
